#
# spec file for package ranger
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ranger
Version:        1.9.1
Release:        lp150.1.2
Summary:        Console File Manager
License:        GPL-3.0
Group:          Productivity/File utilities
Url:            https://ranger.github.io
Source:         https://github.com/ranger/ranger/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       ranger-rpmlintrc
# PATCH-FIX-UPSTREAM ranger.desktop.patch -- Add missing GenericName
Patch0:         ranger.desktop.patch
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       file
Requires:       python3-curses
Recommends:     atool
Recommends:     highlight
Recommends:     mediainfo
Recommends:     w3m
BuildArch:      noarch

%description
Ranger is a console file manager that gives you greater flexibility and a
good overview of your files without having to leave your text console. It
visualizes the directory tree in two dimensions: the directory hierarchy on
one, lists of files on the other, with a preview to the right.

The default keys are similar to those of Vim, Emacs and Midnight Commander,
though ranger is easily controllable with just the arrow keys or the mouse.

%prep
%setup -q
%patch0 -p1
sed -e 's|#!/usr/bin/env python|#!%{_bindir}/python3|' -i doc/tools/*.py
sed -e 's|#!/usr/bin/env bash|#!/bin/bash|' -i ranger/data/scope.sh

%build
python3 ./setup.py build

%install
python3 ./setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot}

rm -rf "%{buildroot}%{_datadir}/doc/ranger"

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%doc AUTHORS CHANGELOG.md README.md HACKING.md
%doc doc/colorschemes.txt
%doc doc/tools
%doc examples
%{_bindir}/ranger
%{_bindir}/rifle
%{python3_sitelib}/ranger_fm-%{version}-*.egg-info
%{python3_sitelib}/ranger
%{_mandir}/man1/ranger.1%{ext_man}
%{_mandir}/man1/rifle.1%{ext_man}
%{_datadir}/applications/%{name}.desktop

%changelog
* Thu Feb 22 2018 aloisio@gmx.com
- Update to version 1.9.1
  * Fixed the rifle config backwards compatibility (regression in
    1.9.0)
  * Fixed the POSIX compatibility of `Makefile`
  * Fixed `--choosefile`, `--choosefiles` and `--choosedir` so
    they work with the process substitution (`>(...)` in Bash)
  * Changed the default `gt` binding to `gp` due to a conflict
  * Changed the help message for `--choosefile`, `--choosefiles`
    and `--choosedir` to avoid confusion
  * Changed the behavior of `:reset` to reload the tags too
  * Added `geeqie` to the default `rifle.conf`
* Sun Jan 28 2018 aloisio@gmx.com
- Update to version 1.9.0
  * Fixed memory leak in w3m image preview
  * Fixed `Q` binding, map it to `quitall` instead of `quit!`
  * Fixed `gR` binding
  * Fixed custom linemode not being applied to files
  * Fixed w3m image display invocation on OpenBSD
  * Fixed broken pager after changing view mode with `~`
  * Added reset of rifle.conf when pressing `<C-R>`
  * Added image-based PDF previews to `scope.sh` (disabled by
    default)
  * Added terminology-based image previews
  * Added check for `$VISUAL` environment variable
  * Added setting `iterm2_font_height` and `iterm2_font_width`
  * Renamed setting `cd_tab_smart` to `cd_tab_fuzzy`
  * Changed command for mercurial integration from `hg` to `chg`
  version 1.9.0b6
  * Fixed crash when parsing corrupted history file
  * Fixed tab completion with `cd -r ...`
  * Fixed crash when previewing files encoded in little-endian
    UTF-16
  * Fixed flicker in previewing symlinked images
  * Fixed detection of location of scope.sh
  * Fixed crash when running ranger from the directory containing
    its package
  * Fixed cursor position after moving half a page down and back up
  * Fixed handling of lines that are too long for the console
  * Added `<F2>` binding to `:rename_append`
  * Avoid dereferencing symlinked directory when starting ranger
    in one
  * Added support for `file://` URIs as path arguments
  * Added setting `save_tabs_on_exit`
  * Added setting `cd_tab_case`, sets case sensitivity of `:cd`
    tab completion
  * Added setting `cd_tab_smart`, allows fuzzy tab completion with
    `:cd`, for example, `:cd /u/lo/b<TAB>` expands to
    `:cd /usr/local/bin`
  * Added setting `global_inode_type_filter` to show only
    directories when running ranger with the new option
    `--show-only-dirs`
  * Added setting `save_backtick_bookmark`, e.g. for easier
    syncing of bookmarks
  * Added setting `one_indexed` to start counting line numbers
    from 1
  * Added rifle.conf entries to list/extract archives without atool
  * Added `:yank` command for simplified definitions of `yn`, `yd`
    & `yp`
  * Added `:narrow` command, which filters selected files
  * Added setting `freeze_files`, bound to `F` key, to avoid
    reloading files
  * Changed `:shell -p ...` to display stderr in pager
  version 1.9.0b5
  * Fixed width calculation of multibyte characters in preview
  * Fixed crash in iTerm2 preview with python 3.5
  version 1.9.0b1
  * Fixed crash when using `Mi` on files without reading
    permissions
  * Fixed natural sorting (`11.jpg` < `100.jpg`)
  * Fixed loss of precision in timestamps when copying
  * Fixed smart case matching in `:travel`
  * Fixed automatically disabling `preview_script` when running as
    root
  * Fixed crash on sshfs disconnect
  * Fixed crash on missing `~/.config/ranger/history`
  * Fixed crash when path not accessible during start-up
  * Fixed automatic tmux title
  * Fixed urxvt image previewing when running tmux
  * Fixed macro expansion in aliased commands
  * Fixed `hidden_filter` option when combined with `:flat`
  * Fixed various other crashes
  * Fixed error message that occasionally pops up when changing
    settings
  * Introduced extensive linting to ensure code quality
  * Added continuous integration.  Patches now require `make test`
    to pass.
  * Added handling of arguments in "$PAGER" environment variable
  * Added quote parsing for `:setlocal path=...`
  * Added `ys` to copy the selection to clipboard
  * Added setting `hostname_in_titlebar`
  * Added setting `wrap_scroll` to wrap cursor around when
    scrolling
  * Added example plugin `plugin_fasd_add.py`
  * Added command `jump_non` to jump to the first non-directory
    file
  * Added additional arguments to the command `:rename_append`
  * Added key binding 'zz' as an alternative to 'zf'
  * Added option `-c` to the `rifle` file opener command
  * Added support for `$XDG_DATA_HOME`
  * Avoid exiting ranger while copying.  Use `:quit!` to quit
    while copying.
  * Improved scope.sh (better performance & readability)
  * Changed `ranger --choosefiles` to return all selected files in
    all paths
  * Changed interpretation of commands: treat tabs as argument
    separators
  * Changed `<C-n>` to open new tab in current directory rather
    than `$HOME`
  * Changed `:quit!` to only close 1 tab.  Use `:quitall` to close
    all tabs.
  * Removed backward compatibility for `options.py`, predecessor
    of `rc.conf`
  * Automatically update bookmarks+tags when renaming them via
    ranger
- New URL and source address.
- Switched to python3
- Spec cleanup
* Wed Dec 27 2017 antoine.belvire@opensuse.org
- Fix wrong conditionals for desktop_database_post(un) calls.
* Mon Dec 11 2017 sogal@volted.net
- Update desktop database upon ranger installation/removal
- Fixed desktop file by adding GenericName entry using
  ranger.desktop.patch
* Sat Jan 21 2017 aloisio@gmx.com
- Update to version 1.8.1
  * Fixed `:scout` break due to incompatible change
    in python 3.6
* Wed Dec 28 2016 jengelh@inai.de
- Trim filler words from description
* Sat Dec 24 2016 aloisio@gmx.com
- Update to version 1.8.0
  * scope.sh is now needed for the now fully scriptable image
    previews
  * Overhaul of version control system integration, now with
    threads
  * Fixed ranger not finding the location of w3mimgdisplay in
    most cases
  * Fixed many minor bugs
  * Added midnight-commander like multipane view, toggleable
    with `~` key. It displays the current directory of all the
    open tabs next to each other.
  * Added autodetect for 256 color support in scope.sh source
    code preview
  * Added macro `%%confdir` that expands to `~/.config/ranger`
    by default
  * Added possibility to toggle/cycle through options with
    `set <option_name>!`
  * Added `Mm`/`Ms` key to enable the linemode showing
    modification time
  * Added `yt`/`dt` keys to toggle whether file is in copy/cut
    buffer
  * Added `line_numbers` setting showing absolute/relative
    line numbers
  * Added `Alt-Left` and `Alt-Right` key bindings to move by
    words in console
  * Added previews for libreoffice files with `odt2txt`
  * Added `preview_images_method=urxvt` option for previewing
    images by changing the urxvt background (requires urxvt
    compiled with pixbuf support)
  * Added `clear_filters_on_dir_change` option
  * Added Travis-CI integration
  * Changed `zi` key to toggle `preview_images` option
  * Improved PEP8 compliance
  * Improved documentation
  * Improved UI by separating file path in title bar with a
    space from the  username/hostname for quick copy&pasting by
    shift+double-clicking on it.
- Dropped ranger.desktop now supplied from upstream
* Sat Nov  5 2016 aloisio@gmx.com
- Update to version 1.7.2
  * Fixed file name arguments passed to "sxiv" and "feh" when
    using ":flat"
  * Fixed removal of empty directories when using ":rename"
  * Fixed free disk space display on Mac OS X
  * Fixed `examples/vim_file_chooser` to work with gvim too
  * Fixed some other rare crashes and bugs
  * Fixed downward mouse wheel scrolling
  * Fixed warning about regex splits being drawin in title bar
    since python3.5
  * Really fixed "S" key binding not working when SHELL=fish
  * Improved doc/cheatsheet.svg
  * Added some entries to rifle.conf
  * Added key bindings pO and pP which work like po and pp but
    queue the operation in a first-in-first-out order.
  version 1.7.1
  * Added doc/cheatsheet.svg
  * Added examples/rc_emacs.conf, a config file adding
    emacs-like key bindings
  * Added "env" keyword in rifle.conf
  * Fixed ":bulkrename" command in python3
  * Fixed "S" key binding not working when SHELL=fish
  version 1.7.0
  * The default editor is now "vim" instead of "nano"
  * Added automatic updates of tags when a file is renamed
    from within ranger
  * Added "preview_images_method" which can be set to "iterm2"
    to use native iTerm2 image previews
  * Added ":rename_append" command to rename files without the
    file extension
  * Added ":linemode" command to change the way the files are
    displayed. Try this out by pressing M followed by one of
    the  suggested keys. New linemodes can be added with
    ranger.api.register_linemode().
  * Added ":filter_inode_type" command to only show
    directories, files or links
  * Added ":meta" command for managing custom file metadata
  * Added ":flat" command for displaying subdirectories
  * Added "solarized" colorscheme
  * Added generic ability to use scope.sh for image previews
  * Added video previews in scope.sh
  * Added option "sort_unicode" to sort according to unicode,
    not ASCII
  * ":mkdir" can now create multiple directory levels (like
    `mkdir -p`)
  * ":help" (key binding "?") is now interactive
  * ":find" (key binding "/") is now case insensitive by
    default
  * "ranger --copy-config=all" now copies a short sample
    commands.py rather than the full one, so that you can
    update ranger without having broken commands. The full
    commands.py is still copied to
    ~/.config/ranger/commands_full.py.
  * Fixed broken copying of symlinks
- Spec cleanup
* Mon Jul 15 2013 pascal.bleser@opensuse.org
- update to 1.6.1
- add required dependency on python-curses
* Thu May 26 2011 pascal.bleser@opensuse.org
- initial version (1.4.3)
